@@ -25,24 +25,6 @@ sub shellquote {
     @_;
 }
 
-push @EXPORT, 'uniq';
-sub uniq {
-    my %seen;
-    grep { not $seen{$_}++ } @_;
-}
-
-##
-## Mimic Text::Glob because it is not in standard library.
-##
-push @EXPORT, 'match_glob';
-sub match_glob {
-    local $_ = shift;
-    s/\?/./g;
-    s/\*/.*/g;
-    my $regex = qr/^$_$/;
-    grep { $_ =~ $regex } @_;
-}
-
 1;
 
 
